@@ -1,56 +1,51 @@
 #!/usr/bin/env python3
 """
-BioQL v5.0.1: Enterprise Quantum Computing with Full QEC Control
+BioQL v6.0.0: Multi-Omics Quantum Computing Platform
 
-BioQL is a quantum computing framework specifically designed for bioinformatics
-applications. It provides a natural language interface for quantum programming
-and integrates with popular quantum computing backends.
+BioQL is a comprehensive quantum computing framework for bioinformatics with
+full multi-omics analysis capabilities including proteomics, metabolomics,
+multi-omics integration, and advanced genomics.
 
-🆕 NEW in v5.0.1 - AWS BRAKET EXAMPLES:
-- **AWS Braket Setup Scripts**: Complete automated setup for Amazon Braket
-- **Example Circuits**: Bell state, GHZ, and more in OpenQASM 3.0
-- **Integration Guides**: Step-by-step AWS Braket + BioQL integration
-- **Verified Results**: 100% quantum entanglement confirmed on SV1
+🎉 NEW in v6.0.0 - MULTI-OMICS EDITION:
+- **Proteomics Module**: Protein analysis, PTM prediction, PPI screening, structure prediction
+- **Metabolomics Module**: Metabolite identification, pathway analysis, flux analysis (FBA/MFA)
+- **Multi-Omics Integration**: Quantum-enhanced data integration across omics layers
+- **Advanced Genomics**: Variant calling, epigenetics (methylation, histone marks), RNA-Seq
 
-🚀 FEATURES from v5.0.0 - FULL QEC CONTROL EDITION:
-- **Full Qubit Management**: Control physical vs logical qubits explicitly
-- **Advanced QEC Codes**: Surface Code, Steane Code, Shor Code implementations
-- **Qualtran Visualization**: Resource estimation and QEC overhead graphs
-- **Error Mitigation**: ZNE, PEC, readout calibration, symmetry verification
-- **QEC Metrics**: Comprehensive fidelity and error rate tracking
-- **Dynamic Pricing**: QEC overhead cost calculation with multipliers
-- **Target Fidelity**: Set minimum fidelity requirements (95-99.9%)
+Proteomics Features:
+- Protein sequence analysis and physicochemical properties
+- Post-translational modification (PTM) site prediction
+- Protein-protein interaction (PPI) prediction
+- Secondary and 3D structure prediction
+- Mass spectrometry analysis
 
-Previous features (v4.1.0):
-- Quantum Error Correction (QEC) Module - Target 95-100% accuracy
-  * OpenFermion: Molecular Hamiltonians (H2, LiH, H2O, N2, BeH2)
-  * Qualtran: QEC gates cost analysis, RSA ModExp factorization
-  * Advanced error mitigation: ZNE, PEC, readout correction, symmetry
-- Multi-backend support: IBM Torino (133 qubits), IonQ, AWS Braket
-- Error mitigation strategies (readout error, ZNE, PEC)
-- Provenance & compliance logging (21 CFR Part 11 aligned)
-- Cryptographic audit trails with signed records
-- Reproducibility tracking with full parameter logging
-- Chemistry benchmarks vs. literature (H2, LiH, H2O, BeH2, N2)
+Metabolomics Features:
+- Metabolite identification (HMDB, KEGG databases)
+- Pathway enrichment analysis
+- Metabolic flux balance analysis (FBA)
+- Metabolic flux analysis (MFA)
+- NMR and MS spectral analysis
 
-✨ Features from v3.1.0:
-- Performance profiling system with <5% overhead
-- Interactive HTML dashboards with Plotly charts
-- Circuit optimization (35% gate/depth reduction)
-- Smart caching (24x speedup with 70% hit rate)
-- Intelligent job batching (18-30% cost savings)
-- Pre-built circuit library (Grover, VQE, QAOA, drug discovery templates)
-- Enhanced semantic NL parsing with context awareness
-- Circuit composition and stitching tools
+Multi-Omics Features:
+- Quantum neural network data integration
+- Regulatory network construction
+- Cross-layer correlation analysis
+- Pathway enrichment across omics
+- Factor analysis and dimensionality reduction
 
-Main Features:
-- Natural language quantum programming (164B+ patterns!)
-- Advanced profiling and performance optimization
-- Circuit library with drug discovery templates
-- Integration with Qiskit and other quantum backends
-- Biological interpretation of quantum results
-- Cloud authentication & billing system
-- Drug discovery and protein folding support
+Advanced Genomics Features:
+- Variant calling (SNPs, InDels, structural variants)
+- DNA methylation analysis (bisulfite sequencing)
+- Histone modification analysis (ChIP-Seq)
+- RNA-Seq differential expression analysis
+- Epigenetic regulation analysis
+
+All Previous Features (v5.x):
+- Full QEC control, AWS Braket integration
+- Drug discovery and CRISPR-QAI modules
+- Provenance logging and compliance
+- Multi-backend quantum execution
+- Natural language quantum programming
 
 Basic Usage:
     >>> from bioql import quantum, QuantumResult
@@ -96,7 +91,7 @@ QEC Module Usage (NEW in v4.0.0):
     >>> print(f"Accuracy: {em.accuracy_original:.1f}% → {em.accuracy_mitigated:.1f}%")
 """
 
-__version__ = "5.7.3"
+__version__ = "6.0.0"
 __author__ = "BioQL Development Team / SpectrixRD"
 __email__ = "bioql@spectrixrd.com"
 __license__ = "MIT"
@@ -443,6 +438,90 @@ except ImportError:
     generate_docking_pdb = None
     PDBDockingGenerator = None
 
+# NEW in v6.0.0 - Proteomics Module
+try:
+    from .proteomics import (
+        analyze_protein_sequence,
+        predict_protein_properties,
+        predict_ptm_sites,
+        predict_phosphorylation,
+        predict_acetylation,
+        predict_protein_protein_interaction,
+        ProteinResult,
+        PTMResult,
+        PPIResult,
+        HAVE_PROTEIN_ANALYSIS
+    )
+except ImportError:
+    analyze_protein_sequence = None
+    predict_protein_properties = None
+    predict_ptm_sites = None
+    predict_phosphorylation = None
+    predict_acetylation = None
+    predict_protein_protein_interaction = None
+    ProteinResult = None
+    PTMResult = None
+    PPIResult = None
+    HAVE_PROTEIN_ANALYSIS = False
+
+# NEW in v6.0.0 - Metabolomics Module
+try:
+    from .metabolomics import (
+        identify_metabolite,
+        quantify_metabolites,
+        analyze_metabolic_pathway,
+        perform_flux_balance_analysis,
+        Metabolite,
+        MetaboliteResult,
+        PathwayResult,
+        FBAResult,
+        HAVE_METABOLITE_ANALYSIS
+    )
+except ImportError:
+    identify_metabolite = None
+    quantify_metabolites = None
+    analyze_metabolic_pathway = None
+    perform_flux_balance_analysis = None
+    Metabolite = None
+    MetaboliteResult = None
+    PathwayResult = None
+    FBAResult = None
+    HAVE_METABOLITE_ANALYSIS = False
+
+# NEW in v6.0.0 - Multi-Omics Integration
+try:
+    from .multiomics import (
+        integrate_omics_layers,
+        build_regulatory_network,
+        IntegratedResult,
+        HAVE_INTEGRATION
+    )
+except ImportError:
+    integrate_omics_layers = None
+    build_regulatory_network = None
+    IntegratedResult = None
+    HAVE_INTEGRATION = False
+
+# NEW in v6.0.0 - Advanced Genomics
+try:
+    from .genomics import (
+        call_variants,
+        analyze_methylation,
+        analyze_rna_seq,
+        Variant,
+        MethylationResult,
+        RNASeqResult,
+        HAVE_VARIANT_CALLING
+    )
+except ImportError:
+    call_variants = None
+    analyze_methylation = None
+    analyze_rna_seq = None
+    Variant = None
+    MethylationResult = None
+    RNASeqResult = None
+    HAVE_VARIANT_CALLING = False
+
 # Define what gets exported when using "from bioql import *"
 __all__ = [
     # Core functionality
@@ -571,6 +650,34 @@ if generate_docking_pdb is not None:
         "PDBDockingGenerator"
     ])
 
+# Add v6.0.0+ Multi-Omics modules if available
+if analyze_protein_sequence is not None:
+    __all__.extend([
+        "analyze_protein_sequence", "predict_protein_properties",
+        "predict_ptm_sites", "predict_phosphorylation", "predict_acetylation",
+        "predict_protein_protein_interaction",
+        "ProteinResult", "PTMResult", "PPIResult"
+    ])
+
+if identify_metabolite is not None:
+    __all__.extend([
+        "identify_metabolite", "quantify_metabolites",
+        "analyze_metabolic_pathway", "perform_flux_balance_analysis",
+        "Metabolite", "MetaboliteResult", "PathwayResult", "FBAResult"
+    ])
+
+if integrate_omics_layers is not None:
+    __all__.extend([
+        "integrate_omics_layers", "build_regulatory_network",
+        "IntegratedResult"
+    ])
+
+if call_variants is not None:
+    __all__.extend([
+        "call_variants", "analyze_methylation", "analyze_rna_seq",
+        "Variant", "MethylationResult", "RNASeqResult"
+    ])
+
 
 def get_version() -> str:
     """Return the current version of BioQL."""
