@@ -10,8 +10,8 @@ from typing import Optional, Dict, Any
 from datetime import datetime
 from loguru import logger
 
-# Your authentication service URL (replace with your production URL)
-BIOQL_AUTH_URL = os.getenv('BIOQL_AUTH_URL', 'https://77007dcfe345.ngrok-free.app')
+# Your authentication service URL (production VPS)
+BIOQL_AUTH_URL = os.getenv('BIOQL_AUTH_URL', 'https://api.bioql.bio')
 BIOQL_LOCAL_AUTH = os.getenv('BIOQL_LOCAL_AUTH', 'http://localhost:5001')
 
 class BioQLAuthError(Exception):
