@@ -913,6 +913,11 @@ class NaturalLanguageParser:
             operations = self.generate_protein_folding_circuit(num_qubits)
             context = BiotechContext.PROTEIN_FOLDING
 
+        elif match.intent == self.IntentType.DRUG_DESIGN:
+            # De novo drug design - same circuit as docking but different interpretation
+            operations = self.generate_drug_discovery_circuit(num_qubits)
+            context = BiotechContext.DRUG_DISCOVERY
+
         elif match.intent == self.IntentType.DRUG_DOCKING:
             operations = self.generate_drug_discovery_circuit(num_qubits)
             context = BiotechContext.DRUG_DISCOVERY
