@@ -34,7 +34,10 @@ LIGAND_SMILES = {
     "nad": "NC(=O)c1ccc[n+](c1)C1OC(COP(=O)(O)OP(=O)(O)OCC2OC(n3cnc4c(N)ncnc43)C(O)C2O)C(O)C1O",
     "paracetamol": "CC(=O)Nc1ccc(O)cc1",
     "viagra": "CCCC1=NN(C2=C1N=C(NC2=O)C3=C(C=CC(=C3)S(=O)(=O)N4CCN(CC4)C)OCC)C",
-    "lipitor": "CC(C)c1c(C(=O)Nc2ccccc2)c(-c2ccccc2)c(-c2ccc(F)cc2)n1CC[C@@H](O)C[C@@H](O)CC(=O)O"
+    "lipitor": "CC(C)c1c(C(=O)Nc2ccccc2)c(-c2ccccc2)c(-c2ccc(F)cc2)n1CC[C@@H](O)C[C@@H](O)CC(=O)O",
+    "semaglutide": "CCCCCCCCCCCCCCCCCC(=O)N[C@@H](CO)C(=O)N[C@@H](CC(C)C)C(=O)N[C@@H](CC1=CC=CC=C1)C(=O)N[C@@H](CC(=O)O)C(=O)N[C@@H](CCC(=O)O)C(=O)N",
+    "liraglutide": "CCCCCCCCCCCCCCCCC(=O)N[C@@H](CCCCN)C(=O)N[C@@H](CO)C(=O)N[C@@H](CC(C)C)C(=O)N[C@@H](CC1=CC=CC=C1)C(=O)N",
+    "ozempic": "CCCCCCCCCCCCCCCCCC(=O)N[C@@H](CO)C(=O)N[C@@H](CC(C)C)C(=O)N[C@@H](CC1=CC=CC=C1)C(=O)N[C@@H](CC(=O)O)C(=O)N[C@@H](CCC(=O)O)C(=O)N"
 }
 
 RECEPTOR_PDB = {
@@ -49,7 +52,13 @@ RECEPTOR_PDB = {
     "spike": "6VXX",  # SARS-CoV-2 Spike protein
     "mtor": "4JSP",  # mTOR kinase
     "kinase": "1ATP",  # Generic kinase
-    "protease": "1MTW"  # Generic protease
+    "protease": "1MTW",  # Generic protease
+    "glp1r": "6B3J",  # GLP-1 Receptor (obesity/diabetes)
+    "glp-1r": "6B3J",  # GLP-1 Receptor (alternative name)
+    "gip": "7DTY",  # GIP Receptor (obesity/diabetes)
+    "gipr": "7DTY",  # GIP Receptor (alternative name)
+    "dpp4": "1X70",  # DPP-4 (diabetes)
+    "sglt2": "5CGD"  # SGLT2 (diabetes)
 }
 
 # ==============================================================================
