@@ -21,8 +21,10 @@ class IntentType(Enum):
     QUANTUM_FOURIER = "qft"
     GROVER_SEARCH = "grover"
     VQE_OPTIMIZATION = "vqe"
-    # IMPORTANT: DRUG_DOCKING before PROTEIN_FOLDING
-    # because docking has more specific keywords (SMILES, PDB)
+    # IMPORTANT: DRUG_DESIGN before DRUG_DOCKING before PROTEIN_FOLDING
+    # DRUG_DESIGN has keywords like "design", "generate", "create new"
+    # DRUG_DOCKING has specific SMILES + PDB
+    DRUG_DESIGN = "drug_design"
     DRUG_DOCKING = "drug_docking"
     PROTEIN_FOLDING = "protein_folding"
     DNA_ANALYSIS = "dna_analysis"
@@ -270,8 +272,11 @@ class MegaPatternMatcher:
             return self._match_entanglement(text)
         elif intent == IntentType.QUANTUM_FOURIER:
             return self._match_qft(text)
-        # IMPORTANT: Check DRUG_DOCKING before PROTEIN_FOLDING
-        # because docking keywords (SMILES, PDB, binding) are more specific
+        # IMPORTANT: Check DRUG_DESIGN before DRUG_DOCKING before PROTEIN_FOLDING
+        # DRUG_DESIGN = "design new drug" (de novo generation)
+        # DRUG_DOCKING = "dock SMILES to PDB" (existing molecule)
+        elif intent == IntentType.DRUG_DESIGN:
+            return self._match_drug_design(text)
         elif intent == IntentType.DRUG_DOCKING:
             return self._match_drug_docking(text)
         elif intent == IntentType.PROTEIN_FOLDING:
@@ -382,6 +387,62 @@ class MegaPatternMatcher:
                         )
         return None
 
+    def _match_drug_design(self, text: str) -> Optional[PatternMatch]:
+        """Match drug design patterns - de novo molecule generation."""
+        # HIGH PRIORITY: Design/generate/create NEW drug/molecule
+        design_keywords = ['design', 'generate', 'create', 'develop', 'discover', 'invent', 'synthesize']
+        new_keywords = ['new', 'novel', 'de novo', 'from scratch']
+        molecule_keywords = ['drug', 'molecule', 'compound', 'ligand', 'agonist', 'antagonist', 'inhibitor']
+
+        # Check for design intent
+        has_design = any(keyword in text for keyword in design_keywords)
+        has_new = any(keyword in text for keyword in new_keywords)
+        has_molecule = any(keyword in text for keyword in molecule_keywords)
+
+        # Strong signal: "design a new drug" or "generate molecule"
+        if has_design and (has_new or has_molecule):
+            # Extract target information
+            params = {'num_qubits': 6}
+
+            # Look for disease/target
+            disease_keywords = {
+                'obesity': 'obesity',
+                'diabetes': 'diabetes',
+                'cancer': 'cancer',
+                'alzheimer': 'alzheimers',
+                'parkinson': 'parkinsons',
+                'hypertension': 'hypertension',
+                'depression': 'depression',
+                'pain': 'pain',
+                'inflammation': 'inflammation'
+            }
+
+            for keyword, disease in disease_keywords.items():
+                if keyword in text:
+                    params['disease'] = disease
+                    break
+
+            # Look for target receptor/protein
+            if 'glp' in text or 'glp-1' in text or 'glp1' in text:
+                params['target'] = 'GLP1R'
+            elif 'gip' in text:
+                params['target'] = 'GIP'
+            elif 'pdb' in text:
+                # Extract PDB ID if mentioned
+                import re
+                pdb_match = re.search(r'\b([0-9][A-Za-z0-9]{3})\b', text)
+                if pdb_match:
+                    params['pdb_id'] = pdb_match.group(1).upper()
+
+            return PatternMatch(
+                intent=IntentType.DRUG_DESIGN,
+                confidence=0.97,
+                extracted_params=params,
+                original_text=text
+            )
+
+        return None
+
     def _match_drug_docking(self, text: str) -> Optional[PatternMatch]:
         """Match drug docking patterns - checks for SMILES, PDB, docking keywords."""
         # HIGH PRIORITY: Check for SMILES or PDB mentions (very specific to docking)
